@@ -1,3 +1,5 @@
+from typedtuples.utils import toString
+
 class TypedTuple:
     def __init__(self, *args, **kwargs):
         self.initialize(args, kwargs)
@@ -19,8 +21,8 @@ class TypedTuple:
             else: it = args[i]
             valid = isinstance(it, t)
             if not valid: raise Exception(
-                f'Expect Type "{t.__name__}" but "{it.__class__.__name__}"'
-                f' (at name "{n}", Item {it}) found.'
+                f'Expect Type "{t.__name__}" but "{it.__class__.__name__}" found.'
+                f' (at name "{n}", Item {toString(it)})'
             )
             setattr(self, n, it)
 
@@ -28,7 +30,7 @@ class TypedTuple:
         res = []
         a = self.__annotations__
         for i in a:
-            res += [f'{i}={getattr(self, i)}']
+            res += [f'{i}={toString(getattr(self, i))}']
         return f'{self.__class__.__name__}( {", ".join(res)} )'
 
     def __repr__(self):
